aboutsummaryrefslogtreecommitdiff
path: root/src/config.rs
diff options
context:
space:
mode:
authorChristian Dürr <contact@christianduerr.com>2017-12-25 22:15:41 +0100
committerJoe Wilm <jwilm@users.noreply.github.com>2018-01-02 08:24:03 -0800
commit9797bd72bca6ee496561714dc1cda4071bebf045 (patch)
tree8d8dece9b8223120873bceff8380f0dc52653427 /src/config.rs
parentaa1f31785e754107fab154002abf9bc0b129aad1 (diff)
downloadalacritty-9797bd72bca6ee496561714dc1cda4071bebf045.tar.gz
alacritty-9797bd72bca6ee496561714dc1cda4071bebf045.zip
Allow faux scroll amount configuration
It is now possible to configure the amount of lines scrolled with faux scrollback.
Diffstat (limited to 'src/config.rs')
-rw-r--r--src/config.rs12
1 files changed, 8 insertions, 4 deletions
diff --git a/src/config.rs b/src/config.rs
index aace4254..e7ab3403 100644
--- a/src/config.rs
+++ b/src/config.rs
@@ -66,9 +66,13 @@ pub struct Mouse {
pub double_click: ClickHandler,
pub triple_click: ClickHandler,
- /// Send up/down arrow when scrolling in alt screen buffer
- #[serde(default="true_bool")]
- pub faux_scrollback: bool,
+ /// up/down arrows sent when scrolling in alt screen buffer
+ #[serde(default="default_faux_scrollback_lines")]
+ pub faux_scrollback_lines: usize,
+}
+
+fn default_faux_scrollback_lines() -> usize {
+ 1
}
impl Default for Mouse {
@@ -80,7 +84,7 @@ impl Default for Mouse {
triple_click: ClickHandler {
threshold: Duration::from_millis(300),
},
- faux_scrollback: true,
+ faux_scrollback_lines: 1,
}
}
}